/// <amd-module name="@typedorm/common/src/metadata/metadata-storage" />
import { AUTO_GENERATE_ATTRIBUTE_STRATEGY, EntityTarget } from '@typedorm/common';
import { IndexOptions, Table } from '../table';
import { AttributeOptionsUniqueType } from '../decorators/attribute.decorator';
import { ScalarType } from '../helpers/scalar-type';
export declare const IsAutoGenerateAttributeRawMetadataOptions: (attr: any) => attr is AutoGenerateAttributeRawMetadataOptions;
export declare type PrimaryKey = SimplePrimaryKey | CompositePrimaryKey;
export declare type SimplePrimaryKey = {
    partitionKey: string;
};
export declare type CompositePrimaryKey = {
    partitionKey: string;
    sortKey: string;
};
export declare type Indexes = {
    [key: string]: IndexOptions;
};
export interface EntityRawMetadataOptions {
    name: string;
    target: EntityTarget<any>;
    primaryKey: PrimaryKey;
    indexes?: Indexes;
    table?: Table;
}
interface BaseAttributeRawMetadataOptions {
    name: string;
    type: any;
    hidden?: boolean;
}
export interface AttributeRawMetadataOptions extends BaseAttributeRawMetadataOptions {
    unique?: AttributeOptionsUniqueType;
    default?: ScalarType | (() => ScalarType);
}
export interface AutoGenerateAttributeRawMetadataOptions extends BaseAttributeRawMetadataOptions {
    strategy: AUTO_GENERATE_ATTRIBUTE_STRATEGY;
    autoUpdate?: boolean;
}
export declare class MetadataStorage {
    private _entities;
    private _attributes;
    constructor();
    getEntityByName(name: string): EntityRawMetadataOptions | undefined;
    hasKnownEntity<Entity>(entityClass: EntityTarget<Entity>): boolean;
    getRawAttributesForEntity<Entity>(entityClass: EntityTarget<Entity>): (AutoGenerateAttributeRawMetadataOptions | AttributeRawMetadataOptions)[];
    getRawEntityByTarget<Entity>(entityClass: EntityTarget<Entity>): EntityRawMetadataOptions;
    addRawAttribute<Entity>(entityClass: EntityTarget<Entity>, attribute: AttributeRawMetadataOptions): void;
    addRawEntity(entity: EntityRawMetadataOptions): void;
    get entities(): EntityRawMetadataOptions[];
    get attributes(): (AutoGenerateAttributeRawMetadataOptions | AttributeRawMetadataOptions)[][];
}
export {};
